# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/message.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2
from machinetalk.protobuf import object_pb2 as machinetalk_dot_protobuf_dot_object__pb2
from machinetalk.protobuf import log_pb2 as machinetalk_dot_protobuf_dot_log__pb2
from machinetalk.protobuf import motcmds_pb2 as machinetalk_dot_protobuf_dot_motcmds__pb2
from machinetalk.protobuf import task_pb2 as machinetalk_dot_protobuf_dot_task__pb2
from machinetalk.protobuf import canon_pb2 as machinetalk_dot_protobuf_dot_canon__pb2
from machinetalk.protobuf import value_pb2 as machinetalk_dot_protobuf_dot_value__pb2
from machinetalk.protobuf import rtapicommand_pb2 as machinetalk_dot_protobuf_dot_rtapicommand__pb2
from machinetalk.protobuf import rtapi_message_pb2 as machinetalk_dot_protobuf_dot_rtapi__message__pb2
from machinetalk.protobuf import config_pb2 as machinetalk_dot_protobuf_dot_config__pb2
from machinetalk.protobuf import preview_pb2 as machinetalk_dot_protobuf_dot_preview__pb2
from machinetalk.protobuf import status_pb2 as machinetalk_dot_protobuf_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/message.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\"machinetalk/protobuf/message.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\x1a!machinetalk/protobuf/object.proto\x1a\x1emachinetalk/protobuf/log.proto\x1a\"machinetalk/protobuf/motcmds.proto\x1a\x1fmachinetalk/protobuf/task.proto\x1a machinetalk/protobuf/canon.proto\x1a machinetalk/protobuf/value.proto\x1a\'machinetalk/protobuf/rtapicommand.proto\x1a(machinetalk/protobuf/rtapi_message.proto\x1a!machinetalk/protobuf/config.proto\x1a\"machinetalk/protobuf/preview.proto\x1a!machinetalk/protobuf/status.proto\"\xed\"\n\tContainer\x12(\n\x04type\x18\x01 \x02(\x0e\x32\x1a.machinetalk.ContainerType\x12\x0b\n\x03tsc\x18\x07 \x01(\x10\x12,\n\x07preview\x18\x08 \x03(\x0b\x32\x14.machinetalk.PreviewB\x05\x92?\x02\x18\x03\x12*\n\x06motcmd\x18\t \x01(\x0b\x32\x1a.machinetalk.MotionCommand\x12*\n\x07motstat\x18\n \x01(\x0b\x32\x19.machinetalk.MotionStatus\x12\x1c\n\rlegacy_motcmd\x18\x0b \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\x1d\n\x0elegacy_motstat\x18\x0c \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\x31\n\rrtapi_message\x18\r \x01(\x0b\x32\x1a.machinetalk.RTAPI_Message\x12\x31\n\ntask_reply\x18\x0e \x01(\x0b\x32\x16.machinetalk.TaskReplyB\x05\x92?\x02\x18\x03\x12\x30\n\rticket_update\x18\x0f \x01(\x0b\x32\x19.machinetalk.TicketUpdate\x12\x15\n\x06syslog\x18\x12 \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\x19\n\nlegacy_nml\x18\x13 \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\x1f\n\x10legacy_motconfig\x18\x14 \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\x0e\n\x06tv_sec\x18\x15 \x01(\x05\x12\x0f\n\x07tv_nsec\x18\x16 \x01(\x05\x12\r\n\x05topic\x18\x17 \x01(\t\x12\x16\n\x0ereply_required\x18\x18 \x01(\x08\x12>\n\x0cinterp_state\x18\x19 \x01(\x0e\x32!.machinetalk.InterpreterStateTypeB\x05\x92?\x02\x18\x03\x12\x13\n\x0binterp_name\x18\x1a \x01(\t\x12\x0c\n\x04rsvp\x18\x1e \x01(\x05\x12/\n\x0bin_reply_to\x18! \x01(\x0e\x32\x1a.machinetalk.ContainerType\x12+\n\nrcs_status\x18# \x01(\x0e\x32\x17.machinetalk.RCS_STATUS\x12\'\n\x06status\x18( \x01(\x0e\x32\x17.machinetalk.StatusType\x12\x0e\n\x06serial\x18- \x01(\x05\x12\x14\n\x0creply_serial\x18\x32 \x01(\x05\x12\x0e\n\x06ticket\x18\x37 \x01(\x05\x12\x14\n\x0creply_ticket\x18< \x01(\x05\x12\x10\n\x08sequence\x18> \x01(\x05\x12\x0e\n\x06\x63redit\x18\x41 \x01(\x05\x12\x13\n\x0bline_number\x18\x42 \x01(\x05\x12\x13\n\x04name\x18\x43 \x01(\tB\x05\x92?\x02\x18\x03\x12\x0c\n\x04note\x18\x44 \x03(\t\x12\x0f\n\x07retcode\x18\x45 \x01(\x05\x12\x13\n\x04uuid\x18H \x01(\x0c\x42\x05\x92?\x02\x18\x03\x12\r\n\x05trace\x18K \x01(\x08\x12\x10\n\x08instance\x18M \x01(\x05\x12(\n\x05value\x18U \x03(\x0b\x32\x12.machinetalk.ValueB\x05\x92?\x02\x18\x03\x12\x32\n\x08rtapicmd\x18V \x01(\x0b\x32\x19.machinetalk.RTAPICommandB\x05\x92?\x02\x18\x03\x12\x45\n\x14service_announcement\x18X \x03(\x0b\x32 .machinetalk.ServiceAnnouncementB\x05\x92?\x02\x18\x03\x12+\n\x04\x63omp\x18\x64 \x03(\x0b\x32\x16.machinetalk.ComponentB\x05\x92?\x02\x18\x03\x12$\n\x03pin\x18\x02 \x03(\x0b\x32\x10.machinetalk.PinB\x05\x92?\x02\x18\x03\x12*\n\x06signal\x18\x03 \x03(\x0b\x32\x13.machinetalk.SignalB\x05\x92?\x02\x18\x03\x12(\n\x05param\x18g \x03(\x0b\x32\x12.machinetalk.ParamB\x05\x92?\x02\x18\x03\x12*\n\x06thread\x18h \x03(\x0b\x32\x13.machinetalk.ThreadB\x05\x92?\x02\x18\x03\x12&\n\x04ring\x18i \x03(\x0b\x32\x11.machinetalk.RingB\x05\x92?\x02\x18\x03\x12(\n\x05group\x18j \x03(\x0b\x32\x12.machinetalk.GroupB\x05\x92?\x02\x18\x03\x12*\n\x06member\x18k \x03(\x0b\x32\x13.machinetalk.MemberB\x05\x92?\x02\x18\x03\x12.\n\x08\x66unction\x18l \x03(\x0b\x32\x15.machinetalk.FunctionB\x05\x92?\x02\x18\x03\x12\x37\n\x07pparams\x18m \x01(\x0b\x32\x1f.machinetalk.ProtocolParametersB\x05\x92?\x02\x18\x03\x12*\n\x06vtable\x18n \x03(\x0b\x32\x13.machinetalk.VtableB\x05\x92?\x02\x18\x03\x12&\n\x04inst\x18o \x03(\x0b\x32\x11.machinetalk.InstB\x05\x92?\x02\x18\x03\x12,\n\x03\x61pp\x18x \x03(\x0b\x32\x18.machinetalk.ApplicationB\x05\x92?\x02\x18\x03\x12/\n\x08launcher\x18\x82\x01 \x03(\x0b\x32\x15.machinetalk.LauncherB\x05\x92?\x02\x18\x03\x12\x15\n\x05index\x18\x83\x01 \x01(\x05\x42\x05\x92?\x02\x18\x03\x12\x33\n\x0blog_message\x18W \x01(\x0b\x32\x17.machinetalk.LogMessageB\x05\x92?\x02\x18\x03\x12\x37\n\ttpexecute\x18\xc8\x01 \x01(\x0b\x32\x1c.machinetalk.TaskPlanExecuteB\x05\x92?\x02\x18\x03\x12?\n\rtpblockdelete\x18\xc9\x01 \x01(\x0b\x32 .machinetalk.TaskPlanBlockDeleteB\x05\x92?\x02\x18\x03\x12\x41\n\x0etpoptionalstop\x18\xca\x01 \x01(\x0b\x32!.machinetalk.TaskPlanOptionalStopB\x05\x92?\x02\x18\x03\x12\x31\n\x06tpopen\x18\xcb\x01 \x01(\x0b\x32\x19.machinetalk.TaskPlanOpenB\x05\x92?\x02\x18\x03\x12:\n\x0etaskplan_reply\x18\xd2\x01 \x01(\x0b\x32\x1a.machinetalk.TaskPlanReplyB\x05\x92?\x02\x18\x03\x12\x34\n\x0ctraj_set_g5x\x18\xac\x02 \x01(\x0b\x32\x1d.machinetalk.Emc_Traj_Set_G5x\x12\x34\n\x0ctraj_set_g92\x18\xb6\x02 \x01(\x0b\x32\x1d.machinetalk.Emc_Traj_Set_G92\x12>\n\x11traj_set_rotation\x18\xc0\x02 \x01(\x0b\x32\".machinetalk.Emc_Traj_Set_Rotation\x12<\n\x10traj_linear_move\x18\xca\x02 \x01(\x0b\x32!.machinetalk.Emc_Traj_Linear_Move\x12\x30\n\ntraj_probe\x18\xd4\x02 \x01(\x0b\x32\x1b.machinetalk.Emc_Traj_Probe\x12@\n\x12traj_circular_move\x18\xde\x02 \x01(\x0b\x32#.machinetalk.Emc_Traj_Circular_Move\x12\x38\n\x0etraj_rigid_tap\x18\xe8\x02 \x01(\x0b\x32\x1f.machinetalk.Emc_Traj_Rigid_Tap\x12@\n\x12traj_set_term_cond\x18\xf2\x02 \x01(\x0b\x32#.machinetalk.Emc_Traj_Set_Term_Cond\x12\x44\n\x14traj_set_spindlesync\x18\xfc\x02 \x01(\x0b\x32%.machinetalk.Emc_Traj_Set_Spindlesync\x12\x30\n\ntraj_delay\x18\x86\x03 \x01(\x0b\x32\x1b.machinetalk.Emc_Traj_Delay\x12\x30\n\nspindle_on\x18\x90\x03 \x01(\x0b\x32\x1b.machinetalk.Emc_Spindle_On\x12\x36\n\rspindle_speed\x18\x9a\x03 \x01(\x0b\x32\x1e.machinetalk.Emc_Spindle_Speed\x12\x38\n\x0espindle_orient\x18\xa4\x03 \x01(\x0b\x32\x1f.machinetalk.Emc_Spindle_Orient\x12T\n\x1cspindle_wait_orient_complete\x18\xae\x03 \x01(\x0b\x32-.machinetalk.Emc_Spindle_Wait_Orient_Complete\x12\x39\n\x0etool_set_offet\x18\xb8\x03 \x01(\x0b\x32 .machinetalk.Emc_Tool_Set_Offset\x12:\n\x0ftraj_set_offset\x18\xc2\x03 \x01(\x0b\x32 .machinetalk.Emc_Traj_Set_Offset\x12\x34\n\x0ctool_prepare\x18\xcc\x03 \x01(\x0b\x32\x1d.machinetalk.Emc_Tool_Prepare\x12:\n\x0ftool_set_number\x18\xd6\x03 \x01(\x0b\x32 .machinetalk.Emc_Tool_Set_Number\x12@\n\x12traj_set_fo_enable\x18\xe0\x03 \x01(\x0b\x32#.machinetalk.Emc_Traj_Set_Fo_Enable\x12@\n\x12traj_set_so_enable\x18\xea\x03 \x01(\x0b\x32#.machinetalk.Emc_Traj_Set_So_Enable\x12@\n\x12traj_set_fh_enable\x18\xf4\x03 \x01(\x0b\x32#.machinetalk.Emc_Traj_Set_Fh_Enable\x12:\n\x0fmotion_adaptive\x18\xfe\x03 \x01(\x0b\x32 .machinetalk.Emc_Motion_Adaptive\x12<\n\x10operator_display\x18\x88\x04 \x01(\x0b\x32!.machinetalk.Emc_Operator_Display\x12\x36\n\roperator_text\x18\x92\x04 \x01(\x0b\x32\x1e.machinetalk.Emc_Operator_Text\x12\x38\n\x0eoperator_error\x18\x9c\x04 \x01(\x0b\x32\x1f.machinetalk.Emc_Operator_Error\x12:\n\x0fmotion_set_dout\x18\xa6\x04 \x01(\x0b\x32 .machinetalk.Emc_Motion_Set_Dout\x12:\n\x0fmotion_set_aout\x18\xb0\x04 \x01(\x0b\x32 .machinetalk.Emc_Motion_Set_Aout\x12\x38\n\x0e\x61ux_input_wait\x18\xba\x04 \x01(\x0b\x32\x1f.machinetalk.Emc_Aux_Input_Wait\x12<\n\x10\x65xec_plugin_call\x18\xc4\x04 \x01(\x0b\x32!.machinetalk.Emc_Exec_Plugin_Ca1l\x12\x38\n\x0eio_plugin_call\x18\xce\x04 \x01(\x0b\x32\x1f.machinetalk.Emc_Io_Plugin_Call\x12?\n\x11\x65mc_status_config\x18\xd8\x04 \x01(\x0b\x32\x1c.machinetalk.EmcStatusConfigB\x05\x92?\x02\x18\x03\x12?\n\x11\x65mc_status_motion\x18\xd9\x04 \x01(\x0b\x32\x1c.machinetalk.EmcStatusMotionB\x05\x92?\x02\x18\x03\x12\x37\n\remc_status_io\x18\xda\x04 \x01(\x0b\x32\x18.machinetalk.EmcStatusIoB\x05\x92?\x02\x18\x03\x12;\n\x0f\x65mc_status_task\x18\xdb\x04 \x01(\x0b\x32\x1a.machinetalk.EmcStatusTaskB\x05\x92?\x02\x18\x03\x12?\n\x11\x65mc_status_interp\x18\xdc\x04 \x01(\x0b\x32\x1c.machinetalk.EmcStatusInterpB\x05\x92?\x02\x18\x03\x12\x37\n\remc_status_ui\x18\xdd\x04 \x01(\x0b\x32\x18.machinetalk.EmcStatusUIB\x05\x92?\x02\x18\x03\x12\x45\n\x12\x65mc_command_params\x18\xe2\x04 \x01(\x0b\x32!.machinetalk.EmcCommandParametersB\x05\x92?\x02\x18\x03:\x06\x92?\x03H\xf4\x03')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_object__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_log__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_motcmds__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_task__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_canon__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_value__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_rtapicommand__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_rtapi__message__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_config__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_preview__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_status__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CONTAINER = _descriptor.Descriptor(
  name='Container',
  full_name='machinetalk.Container',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Container.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tsc', full_name='machinetalk.Container.tsc', index=1,
      number=7, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preview', full_name='machinetalk.Container.preview', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='motcmd', full_name='machinetalk.Container.motcmd', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motstat', full_name='machinetalk.Container.motstat', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='legacy_motcmd', full_name='machinetalk.Container.legacy_motcmd', index=5,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='legacy_motstat', full_name='machinetalk.Container.legacy_motstat', index=6,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='rtapi_message', full_name='machinetalk.Container.rtapi_message', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_reply', full_name='machinetalk.Container.task_reply', index=8,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='ticket_update', full_name='machinetalk.Container.ticket_update', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='syslog', full_name='machinetalk.Container.syslog', index=10,
      number=18, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='legacy_nml', full_name='machinetalk.Container.legacy_nml', index=11,
      number=19, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='legacy_motconfig', full_name='machinetalk.Container.legacy_motconfig', index=12,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='tv_sec', full_name='machinetalk.Container.tv_sec', index=13,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_nsec', full_name='machinetalk.Container.tv_nsec', index=14,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topic', full_name='machinetalk.Container.topic', index=15,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_required', full_name='machinetalk.Container.reply_required', index=16,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interp_state', full_name='machinetalk.Container.interp_state', index=17,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='interp_name', full_name='machinetalk.Container.interp_name', index=18,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rsvp', full_name='machinetalk.Container.rsvp', index=19,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='machinetalk.Container.in_reply_to', index=20,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rcs_status', full_name='machinetalk.Container.rcs_status', index=21,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='machinetalk.Container.status', index=22,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serial', full_name='machinetalk.Container.serial', index=23,
      number=45, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_serial', full_name='machinetalk.Container.reply_serial', index=24,
      number=50, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='machinetalk.Container.ticket', index=25,
      number=55, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_ticket', full_name='machinetalk.Container.reply_ticket', index=26,
      number=60, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='machinetalk.Container.sequence', index=27,
      number=62, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='credit', full_name='machinetalk.Container.credit', index=28,
      number=65, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_number', full_name='machinetalk.Container.line_number', index=29,
      number=66, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Container.name', index=30,
      number=67, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='note', full_name='machinetalk.Container.note', index=31,
      number=68, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='retcode', full_name='machinetalk.Container.retcode', index=32,
      number=69, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='machinetalk.Container.uuid', index=33,
      number=72, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='trace', full_name='machinetalk.Container.trace', index=34,
      number=75, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.Container.instance', index=35,
      number=77, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.Container.value', index=36,
      number=85, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='rtapicmd', full_name='machinetalk.Container.rtapicmd', index=37,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='service_announcement', full_name='machinetalk.Container.service_announcement', index=38,
      number=88, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='comp', full_name='machinetalk.Container.comp', index=39,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Container.pin', index=40,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='signal', full_name='machinetalk.Container.signal', index=41,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Container.param', index=42,
      number=103, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='thread', full_name='machinetalk.Container.thread', index=43,
      number=104, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='ring', full_name='machinetalk.Container.ring', index=44,
      number=105, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='group', full_name='machinetalk.Container.group', index=45,
      number=106, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='member', full_name='machinetalk.Container.member', index=46,
      number=107, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='function', full_name='machinetalk.Container.function', index=47,
      number=108, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='pparams', full_name='machinetalk.Container.pparams', index=48,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='vtable', full_name='machinetalk.Container.vtable', index=49,
      number=110, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='inst', full_name='machinetalk.Container.inst', index=50,
      number=111, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='app', full_name='machinetalk.Container.app', index=51,
      number=120, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='launcher', full_name='machinetalk.Container.launcher', index=52,
      number=130, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.Container.index', index=53,
      number=131, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='log_message', full_name='machinetalk.Container.log_message', index=54,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='tpexecute', full_name='machinetalk.Container.tpexecute', index=55,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='tpblockdelete', full_name='machinetalk.Container.tpblockdelete', index=56,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='tpoptionalstop', full_name='machinetalk.Container.tpoptionalstop', index=57,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='tpopen', full_name='machinetalk.Container.tpopen', index=58,
      number=203, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='taskplan_reply', full_name='machinetalk.Container.taskplan_reply', index=59,
      number=210, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='traj_set_g5x', full_name='machinetalk.Container.traj_set_g5x', index=60,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_g92', full_name='machinetalk.Container.traj_set_g92', index=61,
      number=310, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_rotation', full_name='machinetalk.Container.traj_set_rotation', index=62,
      number=320, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_linear_move', full_name='machinetalk.Container.traj_linear_move', index=63,
      number=330, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_probe', full_name='machinetalk.Container.traj_probe', index=64,
      number=340, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_circular_move', full_name='machinetalk.Container.traj_circular_move', index=65,
      number=350, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_rigid_tap', full_name='machinetalk.Container.traj_rigid_tap', index=66,
      number=360, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_term_cond', full_name='machinetalk.Container.traj_set_term_cond', index=67,
      number=370, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_spindlesync', full_name='machinetalk.Container.traj_set_spindlesync', index=68,
      number=380, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_delay', full_name='machinetalk.Container.traj_delay', index=69,
      number=390, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_on', full_name='machinetalk.Container.spindle_on', index=70,
      number=400, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_speed', full_name='machinetalk.Container.spindle_speed', index=71,
      number=410, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_orient', full_name='machinetalk.Container.spindle_orient', index=72,
      number=420, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_wait_orient_complete', full_name='machinetalk.Container.spindle_wait_orient_complete', index=73,
      number=430, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_set_offet', full_name='machinetalk.Container.tool_set_offet', index=74,
      number=440, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_offset', full_name='machinetalk.Container.traj_set_offset', index=75,
      number=450, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_prepare', full_name='machinetalk.Container.tool_prepare', index=76,
      number=460, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_set_number', full_name='machinetalk.Container.tool_set_number', index=77,
      number=470, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_fo_enable', full_name='machinetalk.Container.traj_set_fo_enable', index=78,
      number=480, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_so_enable', full_name='machinetalk.Container.traj_set_so_enable', index=79,
      number=490, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_set_fh_enable', full_name='machinetalk.Container.traj_set_fh_enable', index=80,
      number=500, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_adaptive', full_name='machinetalk.Container.motion_adaptive', index=81,
      number=510, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='operator_display', full_name='machinetalk.Container.operator_display', index=82,
      number=520, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='operator_text', full_name='machinetalk.Container.operator_text', index=83,
      number=530, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='operator_error', full_name='machinetalk.Container.operator_error', index=84,
      number=540, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_set_dout', full_name='machinetalk.Container.motion_set_dout', index=85,
      number=550, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_set_aout', full_name='machinetalk.Container.motion_set_aout', index=86,
      number=560, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aux_input_wait', full_name='machinetalk.Container.aux_input_wait', index=87,
      number=570, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_plugin_call', full_name='machinetalk.Container.exec_plugin_call', index=88,
      number=580, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='io_plugin_call', full_name='machinetalk.Container.io_plugin_call', index=89,
      number=590, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emc_status_config', full_name='machinetalk.Container.emc_status_config', index=90,
      number=600, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_status_motion', full_name='machinetalk.Container.emc_status_motion', index=91,
      number=601, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_status_io', full_name='machinetalk.Container.emc_status_io', index=92,
      number=602, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_status_task', full_name='machinetalk.Container.emc_status_task', index=93,
      number=603, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_status_interp', full_name='machinetalk.Container.emc_status_interp', index=94,
      number=604, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_status_ui', full_name='machinetalk.Container.emc_status_ui', index=95,
      number=605, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
    _descriptor.FieldDescriptor(
      name='emc_command_params', full_name='machinetalk.Container.emc_command_params', index=96,
      number=610, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\364\003')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=4975,
)

_CONTAINER.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._CONTAINERTYPE
_CONTAINER.fields_by_name['preview'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._PREVIEW
_CONTAINER.fields_by_name['motcmd'].message_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONCOMMAND
_CONTAINER.fields_by_name['motstat'].message_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONSTATUS
_CONTAINER.fields_by_name['rtapi_message'].message_type = machinetalk_dot_protobuf_dot_rtapi__message__pb2._RTAPI_MESSAGE
_CONTAINER.fields_by_name['task_reply'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKREPLY
_CONTAINER.fields_by_name['ticket_update'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TICKETUPDATE
_CONTAINER.fields_by_name['interp_state'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._INTERPRETERSTATETYPE
_CONTAINER.fields_by_name['in_reply_to'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._CONTAINERTYPE
_CONTAINER.fields_by_name['rcs_status'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._RCS_STATUS
_CONTAINER.fields_by_name['status'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._STATUSTYPE
_CONTAINER.fields_by_name['value'].message_type = machinetalk_dot_protobuf_dot_value__pb2._VALUE
_CONTAINER.fields_by_name['rtapicmd'].message_type = machinetalk_dot_protobuf_dot_rtapicommand__pb2._RTAPICOMMAND
_CONTAINER.fields_by_name['service_announcement'].message_type = machinetalk_dot_protobuf_dot_object__pb2._SERVICEANNOUNCEMENT
_CONTAINER.fields_by_name['comp'].message_type = machinetalk_dot_protobuf_dot_object__pb2._COMPONENT
_CONTAINER.fields_by_name['pin'].message_type = machinetalk_dot_protobuf_dot_object__pb2._PIN
_CONTAINER.fields_by_name['signal'].message_type = machinetalk_dot_protobuf_dot_object__pb2._SIGNAL
_CONTAINER.fields_by_name['param'].message_type = machinetalk_dot_protobuf_dot_object__pb2._PARAM
_CONTAINER.fields_by_name['thread'].message_type = machinetalk_dot_protobuf_dot_object__pb2._THREAD
_CONTAINER.fields_by_name['ring'].message_type = machinetalk_dot_protobuf_dot_object__pb2._RING
_CONTAINER.fields_by_name['group'].message_type = machinetalk_dot_protobuf_dot_object__pb2._GROUP
_CONTAINER.fields_by_name['member'].message_type = machinetalk_dot_protobuf_dot_object__pb2._MEMBER
_CONTAINER.fields_by_name['function'].message_type = machinetalk_dot_protobuf_dot_object__pb2._FUNCTION
_CONTAINER.fields_by_name['pparams'].message_type = machinetalk_dot_protobuf_dot_object__pb2._PROTOCOLPARAMETERS
_CONTAINER.fields_by_name['vtable'].message_type = machinetalk_dot_protobuf_dot_object__pb2._VTABLE
_CONTAINER.fields_by_name['inst'].message_type = machinetalk_dot_protobuf_dot_object__pb2._INST
_CONTAINER.fields_by_name['app'].message_type = machinetalk_dot_protobuf_dot_config__pb2._APPLICATION
_CONTAINER.fields_by_name['launcher'].message_type = machinetalk_dot_protobuf_dot_config__pb2._LAUNCHER
_CONTAINER.fields_by_name['log_message'].message_type = machinetalk_dot_protobuf_dot_log__pb2._LOGMESSAGE
_CONTAINER.fields_by_name['tpexecute'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKPLANEXECUTE
_CONTAINER.fields_by_name['tpblockdelete'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKPLANBLOCKDELETE
_CONTAINER.fields_by_name['tpoptionalstop'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKPLANOPTIONALSTOP
_CONTAINER.fields_by_name['tpopen'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKPLANOPEN
_CONTAINER.fields_by_name['taskplan_reply'].message_type = machinetalk_dot_protobuf_dot_task__pb2._TASKPLANREPLY
_CONTAINER.fields_by_name['traj_set_g5x'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_G5X
_CONTAINER.fields_by_name['traj_set_g92'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_G92
_CONTAINER.fields_by_name['traj_set_rotation'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_ROTATION
_CONTAINER.fields_by_name['traj_linear_move'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_LINEAR_MOVE
_CONTAINER.fields_by_name['traj_probe'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_PROBE
_CONTAINER.fields_by_name['traj_circular_move'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_CIRCULAR_MOVE
_CONTAINER.fields_by_name['traj_rigid_tap'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_RIGID_TAP
_CONTAINER.fields_by_name['traj_set_term_cond'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_TERM_COND
_CONTAINER.fields_by_name['traj_set_spindlesync'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_SPINDLESYNC
_CONTAINER.fields_by_name['traj_delay'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_DELAY
_CONTAINER.fields_by_name['spindle_on'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_SPINDLE_ON
_CONTAINER.fields_by_name['spindle_speed'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_SPINDLE_SPEED
_CONTAINER.fields_by_name['spindle_orient'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_SPINDLE_ORIENT
_CONTAINER.fields_by_name['spindle_wait_orient_complete'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_SPINDLE_WAIT_ORIENT_COMPLETE
_CONTAINER.fields_by_name['tool_set_offet'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TOOL_SET_OFFSET
_CONTAINER.fields_by_name['traj_set_offset'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_OFFSET
_CONTAINER.fields_by_name['tool_prepare'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TOOL_PREPARE
_CONTAINER.fields_by_name['tool_set_number'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TOOL_SET_NUMBER
_CONTAINER.fields_by_name['traj_set_fo_enable'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_FO_ENABLE
_CONTAINER.fields_by_name['traj_set_so_enable'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_SO_ENABLE
_CONTAINER.fields_by_name['traj_set_fh_enable'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_TRAJ_SET_FH_ENABLE
_CONTAINER.fields_by_name['motion_adaptive'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_MOTION_ADAPTIVE
_CONTAINER.fields_by_name['operator_display'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_OPERATOR_DISPLAY
_CONTAINER.fields_by_name['operator_text'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_OPERATOR_TEXT
_CONTAINER.fields_by_name['operator_error'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_OPERATOR_ERROR
_CONTAINER.fields_by_name['motion_set_dout'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_MOTION_SET_DOUT
_CONTAINER.fields_by_name['motion_set_aout'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_MOTION_SET_AOUT
_CONTAINER.fields_by_name['aux_input_wait'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_AUX_INPUT_WAIT
_CONTAINER.fields_by_name['exec_plugin_call'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_EXEC_PLUGIN_CA1L
_CONTAINER.fields_by_name['io_plugin_call'].message_type = machinetalk_dot_protobuf_dot_canon__pb2._EMC_IO_PLUGIN_CALL
_CONTAINER.fields_by_name['emc_status_config'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSCONFIG
_CONTAINER.fields_by_name['emc_status_motion'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSMOTION
_CONTAINER.fields_by_name['emc_status_io'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSIO
_CONTAINER.fields_by_name['emc_status_task'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSTASK
_CONTAINER.fields_by_name['emc_status_interp'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSINTERP
_CONTAINER.fields_by_name['emc_status_ui'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCSTATUSUI
_CONTAINER.fields_by_name['emc_command_params'].message_type = machinetalk_dot_protobuf_dot_status__pb2._EMCCOMMANDPARAMETERS
DESCRIPTOR.message_types_by_name['Container'] = _CONTAINER

Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINER,
  __module__ = 'machinetalk.protobuf.message_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Container)
  ))
_sym_db.RegisterMessage(Container)


_CONTAINER.fields_by_name['preview'].has_options = True
_CONTAINER.fields_by_name['preview']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['legacy_motcmd'].has_options = True
_CONTAINER.fields_by_name['legacy_motcmd']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['legacy_motstat'].has_options = True
_CONTAINER.fields_by_name['legacy_motstat']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['task_reply'].has_options = True
_CONTAINER.fields_by_name['task_reply']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['syslog'].has_options = True
_CONTAINER.fields_by_name['syslog']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['legacy_nml'].has_options = True
_CONTAINER.fields_by_name['legacy_nml']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['legacy_motconfig'].has_options = True
_CONTAINER.fields_by_name['legacy_motconfig']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['interp_state'].has_options = True
_CONTAINER.fields_by_name['interp_state']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['name'].has_options = True
_CONTAINER.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['uuid'].has_options = True
_CONTAINER.fields_by_name['uuid']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['value'].has_options = True
_CONTAINER.fields_by_name['value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['rtapicmd'].has_options = True
_CONTAINER.fields_by_name['rtapicmd']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['service_announcement'].has_options = True
_CONTAINER.fields_by_name['service_announcement']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['comp'].has_options = True
_CONTAINER.fields_by_name['comp']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['pin'].has_options = True
_CONTAINER.fields_by_name['pin']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['signal'].has_options = True
_CONTAINER.fields_by_name['signal']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['param'].has_options = True
_CONTAINER.fields_by_name['param']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['thread'].has_options = True
_CONTAINER.fields_by_name['thread']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['ring'].has_options = True
_CONTAINER.fields_by_name['ring']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['group'].has_options = True
_CONTAINER.fields_by_name['group']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['member'].has_options = True
_CONTAINER.fields_by_name['member']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['function'].has_options = True
_CONTAINER.fields_by_name['function']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['pparams'].has_options = True
_CONTAINER.fields_by_name['pparams']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['vtable'].has_options = True
_CONTAINER.fields_by_name['vtable']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['inst'].has_options = True
_CONTAINER.fields_by_name['inst']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['app'].has_options = True
_CONTAINER.fields_by_name['app']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['launcher'].has_options = True
_CONTAINER.fields_by_name['launcher']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['index'].has_options = True
_CONTAINER.fields_by_name['index']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['log_message'].has_options = True
_CONTAINER.fields_by_name['log_message']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['tpexecute'].has_options = True
_CONTAINER.fields_by_name['tpexecute']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['tpblockdelete'].has_options = True
_CONTAINER.fields_by_name['tpblockdelete']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['tpoptionalstop'].has_options = True
_CONTAINER.fields_by_name['tpoptionalstop']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['tpopen'].has_options = True
_CONTAINER.fields_by_name['tpopen']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['taskplan_reply'].has_options = True
_CONTAINER.fields_by_name['taskplan_reply']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_config'].has_options = True
_CONTAINER.fields_by_name['emc_status_config']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_motion'].has_options = True
_CONTAINER.fields_by_name['emc_status_motion']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_io'].has_options = True
_CONTAINER.fields_by_name['emc_status_io']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_task'].has_options = True
_CONTAINER.fields_by_name['emc_status_task']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_interp'].has_options = True
_CONTAINER.fields_by_name['emc_status_interp']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_status_ui'].has_options = True
_CONTAINER.fields_by_name['emc_status_ui']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.fields_by_name['emc_command_params'].has_options = True
_CONTAINER.fields_by_name['emc_command_params']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\030\003'))
_CONTAINER.has_options = True
_CONTAINER._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\364\003'))
# @@protoc_insertion_point(module_scope)
